# This file was auto-generated by Fern from our API Definition.

from .api_status_response import ApiStatusResponse
from .body_get_access_token_extended_token_post import BodyGetAccessTokenExtendedTokenPost
from .chat_gpt_chat_completition_config import ChatGptChatCompletitionConfig
from .chat_gpt_chat_completition_config_stop import ChatGptChatCompletitionConfigStop
from .chat_gpt_chat_completition_request import ChatGptChatCompletitionRequest
from .chat_gpt_chat_completition_request_stop import ChatGptChatCompletitionRequestStop
from .chat_gpt_chat_completition_response import ChatGptChatCompletitionResponse
from .chat_gpt_completition_choice import ChatGptCompletitionChoice
from .chat_gpt_message import ChatGptMessage
from .chat_gpt_role import ChatGptRole
from .chat_gpt_token_usage import ChatGptTokenUsage
from .db_status import DbStatus
from .http_validation_error import HttpValidationError
from .inference_post_response import InferencePostResponse
from .inference_post_response_response import InferencePostResponseResponse
from .inference_read import InferenceRead
from .inference_read_response import InferenceReadResponse
from .inference_request_data import InferenceRequestData
from .inference_response_data import InferenceResponseData
from .inference_response_error import InferenceResponseError
from .inference_response_status import InferenceResponseStatus
from .org_read import OrgRead
from .prompt_read import PromptRead
from .prompt_status import PromptStatus
from .prompt_version_providers import PromptVersionProviders
from .prompt_version_read import PromptVersionRead
from .prompt_version_status import PromptVersionStatus
from .token import Token
from .user_read import UserRead
from .user_roles import UserRoles
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem

__all__ = [
    "ApiStatusResponse",
    "BodyGetAccessTokenExtendedTokenPost",
    "ChatGptChatCompletitionConfig",
    "ChatGptChatCompletitionConfigStop",
    "ChatGptChatCompletitionRequest",
    "ChatGptChatCompletitionRequestStop",
    "ChatGptChatCompletitionResponse",
    "ChatGptCompletitionChoice",
    "ChatGptMessage",
    "ChatGptRole",
    "ChatGptTokenUsage",
    "DbStatus",
    "HttpValidationError",
    "InferencePostResponse",
    "InferencePostResponseResponse",
    "InferenceRead",
    "InferenceReadResponse",
    "InferenceRequestData",
    "InferenceResponseData",
    "InferenceResponseError",
    "InferenceResponseStatus",
    "OrgRead",
    "PromptRead",
    "PromptStatus",
    "PromptVersionProviders",
    "PromptVersionRead",
    "PromptVersionStatus",
    "Token",
    "UserRead",
    "UserRoles",
    "ValidationError",
    "ValidationErrorLocItem",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class UserRoles(str, enum.Enum):
    """
    An enumeration.
    """

    BASIC = "Basic"
    ORG_ADMIN = "OrgAdmin"
    SUPER_ADMIN = "SuperAdmin"

    def visit(
        self,
        basic: typing.Callable[[], T_Result],
        org_admin: typing.Callable[[], T_Result],
        super_admin: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is UserRoles.BASIC:
            return basic()
        if self is UserRoles.ORG_ADMIN:
            return org_admin()
        if self is UserRoles.SUPER_ADMIN:
            return super_admin()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PromptVersionProviders(str, enum.Enum):
    """
    Currently only OpenAI is supported
    """

    OPEN_AI = "OpenAI"

    def visit(self, open_ai: typing.Callable[[], T_Result]) -> T_Result:
        if self is PromptVersionProviders.OPEN_AI:
            return open_ai()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PromptVersionStatus(str, enum.Enum):
    """
    An enumeration.
    """

    DRAFT = "Draft"
    TESTING = "Testing"
    LIVE = "Live"
    ARCHIVED = "Archived"

    def visit(
        self,
        draft: typing.Callable[[], T_Result],
        testing: typing.Callable[[], T_Result],
        live: typing.Callable[[], T_Result],
        archived: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is PromptVersionStatus.DRAFT:
            return draft()
        if self is PromptVersionStatus.TESTING:
            return testing()
        if self is PromptVersionStatus.LIVE:
            return live()
        if self is PromptVersionStatus.ARCHIVED:
            return archived()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ChatGptRole(str, enum.Enum):
    """
    An enumeration.
    """

    SYSTEM = "system"
    USER = "user"
    ASSISTANT = "assistant"

    def visit(
        self,
        system: typing.Callable[[], T_Result],
        user: typing.Callable[[], T_Result],
        assistant: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ChatGptRole.SYSTEM:
            return system()
        if self is ChatGptRole.USER:
            return user()
        if self is ChatGptRole.ASSISTANT:
            return assistant()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class InferenceResponseStatus(str, enum.Enum):
    """
    An enumeration.
    """

    REQUEST_RECEIVED = "RequestReceived"
    PROCESSED = "Processed"
    COMPLETITION_ERROR = "CompletitionError"
    COMPLETITION_TIMEOUT = "CompletitionTimeout"

    def visit(
        self,
        request_received: typing.Callable[[], T_Result],
        processed: typing.Callable[[], T_Result],
        completition_error: typing.Callable[[], T_Result],
        completition_timeout: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is InferenceResponseStatus.REQUEST_RECEIVED:
            return request_received()
        if self is InferenceResponseStatus.PROCESSED:
            return processed()
        if self is InferenceResponseStatus.COMPLETITION_ERROR:
            return completition_error()
        if self is InferenceResponseStatus.COMPLETITION_TIMEOUT:
            return completition_timeout()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .chat_gpt_chat_completition_response import ChatGptChatCompletitionResponse
from .chat_gpt_message import ChatGptMessage
from .chat_gpt_token_usage import ChatGptTokenUsage


class InferenceResponseData(pydantic.BaseModel):
    completed_at: typing.Optional[str]
    completition_duration_seconds: typing.Optional[float]
    is_client_connected_at_finish: typing.Optional[bool]
    is_error: typing.Optional[bool] = pydantic.Field(alias="isError")
    first_message: ChatGptMessage
    token_usage: ChatGptTokenUsage
    raw_response: ChatGptChatCompletitionResponse

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        allow_population_by_field_name = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing

from .resources.authentication.client import AsyncAuthenticationClient, AuthenticationClient
from .resources.inferences.client import AsyncInferencesClient, InferencesClient
from .resources.orgs.client import AsyncOrgsClient, OrgsClient
from .resources.prompt_versions.client import AsyncPromptVersionsClient, PromptVersionsClient
from .resources.prompts.client import AsyncPromptsClient, PromptsClient
from .resources.server_status.client import AsyncServerStatusClient, ServerStatusClient
from .resources.users.client import AsyncUsersClient, UsersClient


class PromptonApi:
    def __init__(self, *, environment: str, token: typing.Optional[str] = None):
        self._environment = environment
        self._token = token
        self.server_status = ServerStatusClient(environment=self._environment, token=self._token)
        self.authentication = AuthenticationClient(environment=self._environment, token=self._token)
        self.prompts = PromptsClient(environment=self._environment, token=self._token)
        self.prompt_versions = PromptVersionsClient(environment=self._environment, token=self._token)
        self.inferences = InferencesClient(environment=self._environment, token=self._token)
        self.orgs = OrgsClient(environment=self._environment, token=self._token)
        self.users = UsersClient(environment=self._environment, token=self._token)


class AsyncPromptonApi:
    def __init__(self, *, environment: str, token: typing.Optional[str] = None):
        self._environment = environment
        self._token = token
        self.server_status = AsyncServerStatusClient(environment=self._environment, token=self._token)
        self.authentication = AsyncAuthenticationClient(environment=self._environment, token=self._token)
        self.prompts = AsyncPromptsClient(environment=self._environment, token=self._token)
        self.prompt_versions = AsyncPromptVersionsClient(environment=self._environment, token=self._token)
        self.inferences = AsyncInferencesClient(environment=self._environment, token=self._token)
        self.orgs = AsyncOrgsClient(environment=self._environment, token=self._token)
        self.users = AsyncUsersClient(environment=self._environment, token=self._token)



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

import httpx
import pydantic

from ...core.api_error import ApiError
from ...core.remove_none_from_headers import remove_none_from_headers
from ...types.api_status_response import ApiStatusResponse


class ServerStatusClient:
    def __init__(self, *, environment: str, token: typing.Optional[str] = None):
        self._environment = environment
        self._token = token

    def get_status(self) -> ApiStatusResponse:
        _response = httpx.request(
            "GET",
            urllib.parse.urljoin(f"{self._environment}/", "status"),
            headers=remove_none_from_headers(
                {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
            ),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ApiStatusResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncServerStatusClient:
    def __init__(self, *, environment: str, token: typing.Optional[str] = None):
        self._environment = environment
        self._token = token

    async def get_status(self) -> ApiStatusResponse:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "GET",
                urllib.parse.urljoin(f"{self._environment}/", "status"),
                headers=remove_none_from_headers(
                    {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
                ),
                timeout=60,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ApiStatusResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .user_roles import UserRoles


class UserRead(pydantic.BaseModel):
    id: typing.Optional[str] = pydantic.Field(alias="_id")
    created_at: typing.Optional[str]
    created_by_user_id: typing.Optional[str]
    created_by_org_id: typing.Optional[str]
    full_name: typing.Optional[str] = pydantic.Field(description=("`non-empty`\n"))
    disabled: typing.Optional[bool]
    role: typing.Optional[UserRoles]
    org_id: str
    email: str

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        allow_population_by_field_name = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing

from .inference_response_data import InferenceResponseData
from .inference_response_error import InferenceResponseError

InferenceReadResponse = typing.Union[InferenceResponseData, InferenceResponseError]



# This file was auto-generated by Fern from our API Definition.

from . import authentication, inferences, orgs, prompt_versions, prompts, server_status, users

__all__ = ["authentication", "inferences", "orgs", "prompt_versions", "prompts", "server_status", "users"]



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

import httpx
import pydantic

from ...core.api_error import ApiError
from ...core.jsonable_encoder import jsonable_encoder
from ...core.remove_none_from_headers import remove_none_from_headers
from ...errors.bad_request_error import BadRequestError
from ...errors.not_found_error import NotFoundError
from ...errors.unauthorized_error import UnauthorizedError
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.org_read import OrgRead

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class OrgsClient:
    def __init__(self, *, environment: str, token: typing.Optional[str] = None):
        self._environment = environment
        self._token = token

    def get_org_list(self) -> typing.List[OrgRead]:
        _response = httpx.request(
            "GET",
            urllib.parse.urljoin(f"{self._environment}/", "orgs"),
            headers=remove_none_from_headers(
                {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
            ),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.List[OrgRead], _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def add_org(self, *, name: str, access_keys: typing.Optional[typing.Dict[str, str]] = OMIT) -> typing.Any:
        _request: typing.Dict[str, typing.Any] = {"name": name}
        if access_keys is not OMIT:
            _request["access_keys"] = access_keys
        _response = httpx.request(
            "POST",
            urllib.parse.urljoin(f"{self._environment}/", "orgs"),
            json=jsonable_encoder(_request),
            headers=remove_none_from_headers(
                {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
            ),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.Any, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_current_user_org(self) -> OrgRead:
        _response = httpx.request(
            "GET",
            urllib.parse.urljoin(f"{self._environment}/", "orgs/me"),
            headers=remove_none_from_headers(
                {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
            ),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(OrgRead, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_org_by_id(self, id: str) -> OrgRead:
        _response = httpx.request(
            "GET",
            urllib.parse.urljoin(f"{self._environment}/", f"orgs/{id}"),
            headers=remove_none_from_headers(
                {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
            ),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(OrgRead, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_org(
        self, id: str, *, name: typing.Optional[str] = OMIT, access_keys: typing.Optional[typing.Dict[str, str]] = OMIT
    ) -> OrgRead:
        _request: typing.Dict[str, typing.Any] = {}
        if name is not OMIT:
            _request["name"] = name
        if access_keys is not OMIT:
            _request["access_keys"] = access_keys
        _response = httpx.request(
            "PATCH",
            urllib.parse.urljoin(f"{self._environment}/", f"orgs/{id}"),
            json=jsonable_encoder(_request),
            headers=remove_none_from_headers(
                {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
            ),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(OrgRead, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncOrgsClient:
    def __init__(self, *, environment: str, token: typing.Optional[str] = None):
        self._environment = environment
        self._token = token

    async def get_org_list(self) -> typing.List[OrgRead]:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "GET",
                urllib.parse.urljoin(f"{self._environment}/", "orgs"),
                headers=remove_none_from_headers(
                    {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
                ),
                timeout=60,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.List[OrgRead], _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def add_org(self, *, name: str, access_keys: typing.Optional[typing.Dict[str, str]] = OMIT) -> typing.Any:
        _request: typing.Dict[str, typing.Any] = {"name": name}
        if access_keys is not OMIT:
            _request["access_keys"] = access_keys
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "POST",
                urllib.parse.urljoin(f"{self._environment}/", "orgs"),
                json=jsonable_encoder(_request),
                headers=remove_none_from_headers(
                    {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
                ),
                timeout=60,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.Any, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_current_user_org(self) -> OrgRead:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "GET",
                urllib.parse.urljoin(f"{self._environment}/", "orgs/me"),
                headers=remove_none_from_headers(
                    {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
                ),
                timeout=60,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(OrgRead, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_org_by_id(self, id: str) -> OrgRead:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "GET",
                urllib.parse.urljoin(f"{self._environment}/", f"orgs/{id}"),
                headers=remove_none_from_headers(
                    {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
                ),
                timeout=60,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(OrgRead, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_org(
        self, id: str, *, name: typing.Optional[str] = OMIT, access_keys: typing.Optional[typing.Dict[str, str]] = OMIT
    ) -> OrgRead:
        _request: typing.Dict[str, typing.Any] = {}
        if name is not OMIT:
            _request["name"] = name
        if access_keys is not OMIT:
            _request["access_keys"] = access_keys
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "PATCH",
                urllib.parse.urljoin(f"{self._environment}/", f"orgs/{id}"),
                json=jsonable_encoder(_request),
                headers=remove_none_from_headers(
                    {"Authorization": f"Bearer {self._token}" if self._token is not None else None}
                ),
                timeout=60,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(OrgRead, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .chat_gpt_chat_completition_config_stop import ChatGptChatCompletitionConfigStop


class ChatGptChatCompletitionConfig(pydantic.BaseModel):
    model: typing.Optional[str] = pydantic.Field(description=("`non-empty`\n"))
    temperature: typing.Optional[float]
    top_p: typing.Optional[float]
    stop: typing.Optional[ChatGptChatCompletitionConfigStop]
    max_tokens: typing.Optional[int]
    presence_penalty: typing.Optional[float]
    frequency_penalty: typing.Optional[float]
    logit_bias: typing.Optional[typing.Dict[str, int]]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .errors import BadRequestError, NotFoundError, UnauthorizedError, UnprocessableEntityError
from .resources import authentication, inferences, orgs, prompt_versions, prompts, server_status, users
from .types import (
    ApiStatusResponse,
    BodyGetAccessTokenExtendedTokenPost,
    ChatGptChatCompletitionConfig,
    ChatGptChatCompletitionConfigStop,
    ChatGptChatCompletitionRequest,
    ChatGptChatCompletitionRequestStop,
    ChatGptChatCompletitionResponse,
    ChatGptCompletitionChoice,
    ChatGptMessage,
    ChatGptRole,
    ChatGptTokenUsage,
    DbStatus,
    HttpValidationError,
    InferencePostResponse,
    InferencePostResponseResponse,
    InferenceRead,
    InferenceReadResponse,
    InferenceRequestData,
    InferenceResponseData,
    InferenceResponseError,
    InferenceResponseStatus,
    OrgRead,
    PromptRead,
    PromptStatus,
    PromptVersionProviders,
    PromptVersionRead,
    PromptVersionStatus,
    Token,
    UserRead,
    UserRoles,
    ValidationError,
    ValidationErrorLocItem,
)

__all__ = [
    "ApiStatusResponse",
    "BadRequestError",
    "BodyGetAccessTokenExtendedTokenPost",
    "ChatGptChatCompletitionConfig",
    "ChatGptChatCompletitionConfigStop",
    "ChatGptChatCompletitionRequest",
    "ChatGptChatCompletitionRequestStop",
    "ChatGptChatCompletitionResponse",
    "ChatGptCompletitionChoice",
    "ChatGptMessage",
    "ChatGptRole",
    "ChatGptTokenUsage",
    "DbStatus",
    "HttpValidationError",
    "InferencePostResponse",
    "InferencePostResponseResponse",
    "InferenceRead",
    "InferenceReadResponse",
    "InferenceRequestData",
    "InferenceResponseData",
    "InferenceResponseError",
    "InferenceResponseStatus",
    "NotFoundError",
    "OrgRead",
    "PromptRead",
    "PromptStatus",
    "PromptVersionProviders",
    "PromptVersionRead",
    "PromptVersionStatus",
    "Token",
    "UnauthorizedError",
    "UnprocessableEntityError",
    "UserRead",
    "UserRoles",
    "ValidationError",
    "ValidationErrorLocItem",
    "authentication",
    "inferences",
    "orgs",
    "prompt_versions",
    "prompts",
    "server_status",
    "users",
]
